.. _spkg_rfc3986_validator:

rfc3986_validator: Pure python rfc3986 validator
================================================

Description
-----------

Pure python rfc3986 validator

License
-------

MIT license

Upstream Contact
----------------

https://pypi.org/project/rfc3986-validator/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    0.1.1

version_requirements.txt::

    rfc3986-validator

Equivalent System Packages
--------------------------

(none known)
